@@ -8,7 +8,7 @@
 # 8-Apr-2020 jdw change testCache() conditions to specifically track missing matched reference Id codes.
 #
 ##
-__docformat__ = "restructuredtext en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
